@@ -20,6 +20,7 @@
 */
 
 #include "agentwidget.h"
+#include "helper_p.h"
 #include "agentconfigdialog.h"
 #include "akonadiconsole_debug.h"
 #include "kpimtextedit/plaintexteditorwidget.h"
@@ -54,7 +55,7 @@
 class TextDialog : public QDialog
 {
 public:
-    TextDialog(QWidget *parent = Q_NULLPTR)
+    explicit TextDialog(QWidget *parent = nullptr)
         : QDialog(parent)
     {
         QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok);
@@ -175,7 +176,7 @@ void AgentWidget::slotDataChanged(const QModelIndex &topLeft, const QModelIndex
         selectedRows.append(ui.instanceWidget->view()->selectionModel()->currentIndex());
     }
     QList<int> rows;
-    Q_FOREACH (const QModelIndex &index, selectedRows) {
+    for (const QModelIndex &index : qAsConst(selectedRows)) {
         rows.append(index.row());
     }
     std::sort(rows.begin(), rows.end());
@@ -188,7 +189,7 @@ void AgentWidget::slotDataChanged(const QModelIndex &topLeft, const QModelIndex
 
 void AgentWidget::removeAgent()
 {
-    AgentInstance::List list = ui.instanceWidget->selectedAgentInstances();
+    const AgentInstance::List list = ui.instanceWidget->selectedAgentInstances();
     if (!list.isEmpty()) {
         if (KMessageBox::questionYesNo(this,
                                        i18np("Do you really want to delete the selected agent instance?",
@@ -200,7 +201,7 @@ void AgentWidget::removeAgent()
                                        QString(),
                                        KMessageBox::Dangerous)
                 == KMessageBox::Yes) {
-            foreach (const AgentInstance &agent, list) {
+            for (const AgentInstance &agent : list) {
                 AgentManager::self()->removeInstance(agent);
             }
         }
@@ -228,9 +229,9 @@ void AgentWidget::configureAgentRemote()
 
 void AgentWidget::synchronizeAgent()
 {
-    AgentInstance::List list = ui.instanceWidget->selectedAgentInstances();
+    const AgentInstance::List list = ui.instanceWidget->selectedAgentInstances();
     if (!list.isEmpty())
-        foreach (AgentInstance agent, list) {
+        for (AgentInstance agent : list) {
             agent.synchronize();
         }
 }
@@ -296,18 +297,18 @@ void AgentWidget::showChangeNotifications()
 
 void AgentWidget::synchronizeTree()
 {
-    AgentInstance::List list = ui.instanceWidget->selectedAgentInstances();
+    const AgentInstance::List list = ui.instanceWidget->selectedAgentInstances();
     if (!list.isEmpty())
-        foreach (AgentInstance agent, list) {
+        for (AgentInstance agent : list) {
             agent.synchronizeCollectionTree();
         }
 }
 
 void AgentWidget::abortAgent()
 {
-    AgentInstance::List list = ui.instanceWidget->selectedAgentInstances();
+    const AgentInstance::List list = ui.instanceWidget->selectedAgentInstances();
     if (!list.isEmpty())
-        foreach (const AgentInstance &agent, list) {
+        for (const AgentInstance &agent : list) {
             agent.abortCurrentTask();
         }
 }
